@@ -20,7 +20,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-  #include <cheese-config.h>
+  #include <config.h>
 #endif
 
 #include "eog-thumb-nav.h"
